@@ -115,7 +115,7 @@ Shlomo Yona shlomo@cs.haifa.ac.il
 
 =head1 COPYRIGHT
 
-Copyright (c) 2001-2004 Shlomo Yona. All rights reserved.
+Copyright (c) 2001-2005 Shlomo Yona. All rights reserved.
 
 =head1 LICENSE
 
@@ -155,7 +155,7 @@ require Exporter;
 use Carp qw/cluck/;
 use utf8;
 
-our $VERSION = '0.11';
+our $VERSION = '0.12';
 
 our @ISA = qw( Exporter );
 our @EXPORT_OK = qw( get_sentences get_EOS set_EOS);
@@ -228,13 +228,25 @@ sub sentence_breaking {
 	## double new-line means a different sentence.
 	$text=~s/\n\s*\n/$EOS/gs;
 	## break by end-of-sentence just before closing quotes/punct. and opening quotes/punct.
-	$text=~s/(\p{IsEndOfSentenceCharacter}['"\p{ClosePunctuation}\p{OpenPunctuation}]?\s)/$1$EOS/gs;
+	$text=~s/(\p{IsEndOfSentenceCharacter}+(['"\p{ClosePunctuation}])?\s+)/$1$EOS/gs;
+	$text=~s/(['"\p{ClosePunctuation}]\s*\p{IsEndOfSentenceCharacter}+)/$1$EOS/gs;
+
 	# breake also when single letter comes before punc.
 	$text=~s/(\s\w\p{IsEndOfSentenceCharacter})/$1$EOS/gs; 
+
 	## unbreak a series of alphanum/end-of-sentence within punctuation before an EOS
 	$text=~s/(\p{Punctuation}[\w\p{IsEndOfSentenceCharacter}]+\p{Punctuation}\s*)$EOS/$1/gs; 
-	## re-break stuff like ...
-	$text=~s/(\p{IsEndOfSentenceCharacter}{3,}\s+)/$1$EOS/gs;
+	## re-break stuff
+	$text=~s/(\p{IsEndOfSentenceCharacter}+['"\p{ClosePunctuation}]?\s+)(?!$EOS)/$1$EOS/gs;
+
+
+	## unbreak stuff like: VAV-(!)
+	$text=~s/$EOS(\s*(?:\x{05D5}-?(?:\w|\s)*)?['"\p{OpenPunctuation}]\s*\p{IsEndOfSentenceCharacter}+['"\p{ClosePunctuation}]\s*)/$1/gs;
+	## unbreak stuff like: '?!'
+	$text=~s/(['"\p{OpenPunctuation}]\s*\p{IsEndOfSentenceCharacter}+['"\p{ClosePunctuation}]\s*)$EOS/$1/gs;
+	## unbreak stuff like: 'i.b.m.' followed by text
+	$text=~s/(\p{IsEndOfSentenceCharacter}\w+\p{IsEndOfSentenceCharacter}\p{Punctuation}*\s*)$EOS/$1/gs;
+
 	return $text;
 }
 
